

!!! Listing 1

// Zugriff auf die Quelle mit HTTP-POST, 
// entspricht dem Ausfllen eines Formulars

daten =
postURL("http://www.wetter.de/plz/citysearch.cfm",
        "plz=64331").content;

/////////////////////////////////////////////////////
// Variante 1: Extraktion mit fehlertolerantem Parser
/////////////////////////////////////////////////////

// Schritt 1: Definition einer Parser-Regel

rule wetter_regel : xml is
  .+                       // berspringe beliebige Zeichen bis
  'HEUTE'                  // zur Zeichenkette 'HEUTE'
  .+                       // berspringe ...
  temperatur = '-'? [0-9]+ // Binde nchste Zahl an Variable
               ' ?C'   .+  // berspringe ...
  regen =      [0-9]+      // Binde nchste Zahl an Variable
               ' %'    .+  // berspringe ...
  wind =       [0-9]+      // Binde nchste Zahl an Variable
               ' km/h' .+  // berspringe ...

// Anweisungsblock der Regel, erzeugt ein XML-DOM

  do
    xml = <wetter>
            <temperatur> temperatur </temperatur>,
            <regen> regen </regen>,
            <wind> wind </wind>
          </wetter>;
  end
end

// Schritt 2: Aufruf der Regel mit den Quelldaten
xml = wetter_regel.parse(daten);

///////////////////////////////////////////
// Variante 2: Navigation ber DOM-Struktur
///////////////////////////////////////////
// Schritt 1: Aufbau eines HTML-DOM
dokument   = DOM.fromHTML(daten);

// Schritt 2: Zugriff ber die DOM-Struktur
wetterinfo =
dokument.html.body.table.tr.td.table.tr.td.table.tr.td.table[1].tr[3].td;

// Schritt 3: Zuweisen des Inhalts an Variablen 
// und Nachbearbeitung mit regulren Ausdrcken

temperatur = (wetterinfo[1].text() =~ "(.+) ?C"  )[0];
regen      = (wetterinfo[2].text() =~ "(.+) %"   )[0];
wind       = (wetterinfo[5].text() =~ "(.+) km/h")[0];

// Schritt 4: Erzeugen des XML-DOM, Einsetzen der Variablen

xml = <wetter>
        <temperatur> temperatur </temperatur>,
        <regen> regen </regen>,
        <wind> wind </wind>
      </wetter>;


!!! Listing 2

<!ELEMENT golfdemo ( golfplatz+ )>

<!-- Aus Quelle www.golffuehrer.de -->

<!ELEMENT golfplatz
 ( adresse, greenfee?, platz?, policy,
   handicap, wetter, route )
>
<!ATTLIST golfplatz
          id    ID          #REQUIRED
          href  CDATA   #REQUIRED 
>
<!ELEMENT greenfee         ( #PCDATA )>
<!ELEMENT handicap         ( #PCDATA )>
<!ELEMENT policy           ( #PCDATA )>

<!ELEMENT adresse
 (club, strasse?, plz, stadt, telefon, fax?)
>
<!ELEMENT club             ( #PCDATA )>
<!ELEMENT strasse          ( #PCDATA )>
<!ELEMENT plz              ( #PCDATA )>
<!ELEMENT stadt            ( #PCDATA )>
<!ELEMENT vorwahl          ( #PCDATA )>
<!ELEMENT telefon          ( #PCDATA )>
<!ELEMENT fax              ( #PCDATA )>

<!ELEMENT platz 
 (kurzbeschreibung?, loecher, laenge?)
 >
<!ELEMENT kurzbeschreibung ( #PCDATA )>
<!ELEMENT loecher          ( #PCDATA )>
<!ELEMENT laenge           ( #PCDATA )>

<!-- Aus Quelle www.routenplanung.de -->

<!ELEMENT route
 ( nach, entfernung, fahrzeit, karte )
>
<!ELEMENT nach             ( #PCDATA )>
<!ELEMENT entfernung       ( #PCDATA )>
<!ELEMENT fahrzeit         ( #PCDATA )>
<!ELEMENT karte            ( #PCDATA )>

<!-- Aus Quelle www.wetter.de -->

<!ELEMENT wetter 
 (datum, temperatur, regen, wind, prognose)
>
<!ELEMENT datum            ( #PCDATA )>
<!ELEMENT temperatur       ( #PCDATA )>
<!ELEMENT regen            ( #PCDATA )>
<!ELEMENT wind             ( #PCDATA )>
<!ELEMENT prognose         ( #PCDATA )>

!!! Listing 3

<golfdemo>(
  select
       <golfplatz  id=golfplatz.getAttribute("id")  
                   href=golfplatz.getAttribute("href")>
          golfplatz.adresse,
          <greenfee>
             golfplatz.greenfee.wochentag.text()
          </greenfee>
          golfplatz.platz,
          golfplatz.policy,
          <handicap>
             golfplatz.handicap.wochentag.text()
          </handicap>,
          <wetter>
             wetter.datum, wetter.temperatur, wetter.regen,
             wetter.wind, wetter.prognose
          </wetter>,
          <route>
             route.nach, route.entfernung,
             route.fahrzeit, route.karte
          </route>
        </golfplatz>
 from
         route     in select r from r in Routen()
                      where r.von.int() == 64293,
         golfplatz in select g from g in Golfplatz(route)
                      where g.handicap.wochentag.int() >= 36,
         wetter    in Wetter(route)
 where
         wetter.datum.int() == 981001
     and golfplatz.greenfee.wochentag.int() <= 100
     and route.fahrzeit.int() <= 40
).sortDesc(fun $1.platz.greenfee.int() end)
</golfdemo>

